{% load i18n %}

<thead>
  <tr>
    <th>{% trans "Level" %}</th>
    <th>{% trans "App" %}</th>
    <th>{% trans "Asctime" %}</th>
    <th>{% trans "Logger" %}</th>
    <th>{% trans "Message" %}</th>
    <th>&nbsp;</th>
  </tr>
</thead>
