{% load static from staticfiles %}{% load i18n %}{% load l10n %}{% load log4django %}<!DOCTYPE html>
<html>
  <head>
    <title>{{ PAGE_TITLE }}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap -->
    <link href="{% static "log4django/css/bootstrap.min.css" %}" rel="stylesheet" media="screen">
    <link href="{% static "log4django/css/log4django.css" %}" rel="stylesheet" media="screen">
    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="{% static "log4django/assets/js/html5shiv.js" %}"></script>
      <script src="{% static "log4django/assets/js/respond.min.js" %}"></script>
    <![endif]-->
  </head>
  <body>
    <!-- Fixed navbar -->
    <div id="navbar" class="navbar navbar-default navbar-top">
      <div class="container">
        <div class="navbar-header">
          <a class="navbar-brand" href="{% url "log4django:logrecord_list" %}">{{ PAGE_TITLE }}</a>
        </div>
        <div class="navbar-collapse collapse">
          <ul class="nav navbar-nav">
            <li class="active"><a href="{% url 'log4django:logrecord_list' %}">{% trans "Home" %}</a></li>
            <li class="dropdown">
              <a href="#" class="dropdown-toggle" data-toggle="dropdown">{% trans "Export" %}<b class="caret"></b></a>
              <ul class="dropdown-menu">
                <li><a href="{% url 'log4django:csv_export' %}?{{ request.GET.urlencode }}">CSV</a></li>
              </ul>
            </li>
          </ul>
        </div><!--/.nav-collapse -->
      </div>
    </div>

    <div class="container-liquid">
      {% block content %}{% endblock %}
    </div>

    <!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
    <script src="{% static "log4django/js/jquery-1.8.2.min.js" %}"></script>
    <!-- Include all compiled plugins (below), or include individual files as needed -->
    <script src="{% static "log4django/js/bootstrap.min.js" %}"></script>
    <!-- Include log4django custom routines -->
    <script src="{% static "log4django/js/log4django.js" %}"></script>
  </body>
</html>