{% extends "log4django/bootstrap/base.html" %}
{% load l10n %}
{% load i18n %}

{% block content %}
  <table class="table" id="logRecordDetail{{ record.pk|unlocalize }}">
    {% include "log4django/bootstrap/logrecord/partials/table_head.html" %}
    <tbody>
      {% include "log4django/bootstrap/logrecord/partials/table_row.html" with record=record %}
    </tbody>
  </table>

  <h3>{% trans "Requests related" %}</h3>
  <table class="table" id="logRecordRelated{{ record.request_id }}">
    {% include "log4django/bootstrap/logrecord/partials/table_head.html" %}
    <tbody>
      {% for item in related %}
        {% include "log4django/bootstrap/logrecord/partials/table_row.html" with record=item %}
      {%  empty %}
        <td colspan="5">{% trans "No related items." %}</td>
      {% endfor %}
    </tbody>
  </table>
{% endblock %}